@@ -2,7 +2,7 @@
 // detail/task_io_service_thread_info.hpp
 // ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //
-// Copyright (c) 2003-2013 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -15,7 +15,6 @@
 # pragma once
 #endif // defined(_MSC_VER) && (_MSC_VER >= 1200)
 
-#include <boost/asio/detail/event.hpp>
 #include <boost/asio/detail/op_queue.hpp>
 #include <boost/asio/detail/thread_info_base.hpp>
 
@@ -30,10 +29,8 @@ class task_io_service_operation;
 
 struct task_io_service_thread_info : public thread_info_base
 {
-  event* wakeup_event;
   op_queue<task_io_service_operation> private_op_queue;
   long private_outstanding_work;
-  task_io_service_thread_info* next;
 };
 
 } // namespace detail
