@@ -7,6 +7,7 @@
 #if !defined(BOOST_FUSION_FOR_EACH_FWD_HPP_INCLUDED)
 #define BOOST_FUSION_FOR_EACH_FWD_HPP_INCLUDED
 
+#include <boost/fusion/support/config.hpp>
 #include <boost/fusion/support/is_sequence.hpp>
 #include <boost/utility/enable_if.hpp>
 
@@ -19,8 +20,8 @@ namespace boost { namespace fusion
     }
 
     template <typename Sequence, typename F>
-    inline
-    typename
+    BOOST_CXX14_CONSTEXPR BOOST_FUSION_GPU_ENABLED
+    inline typename
         enable_if<
             traits::is_sequence<Sequence>
           , void
@@ -28,8 +29,8 @@ namespace boost { namespace fusion
     for_each(Sequence& seq, F const& f);
 
     template <typename Sequence, typename F>
-    inline
-    typename
+    BOOST_CXX14_CONSTEXPR BOOST_FUSION_GPU_ENABLED
+    inline typename
         enable_if<
             traits::is_sequence<Sequence>
           , void
