@@ -37,9 +37,17 @@ struct enrichment_info
         , startable(true)
         , count_left(0)
         , count_right(0)
+        , rank(-1)
         , zone(-1)
+        , region_id(-1)
+        , isolated(false)
     {}
 
+    inline signed_size_type get_next_turn_index() const
+    {
+        return next_ip_index == -1 ? travels_to_ip_index : next_ip_index;
+    }
+
     // vertex to which is free travel after this IP,
     // so from "segment_index+1" to "travels_to_vertex_index", without IP-s,
     // can be -1
@@ -56,7 +64,10 @@ struct enrichment_info
     // Counts if polygons left/right of this operation
     std::size_t count_left;
     std::size_t count_right;
+    signed_size_type rank; // in cluster
     signed_size_type zone; // open zone, in cluster
+    signed_size_type region_id;
+    bool isolated;
 };
 
 
