@@ -2,7 +2,7 @@
 // buffer.cpp
 // ~~~~~~~~~~
 //
-// Copyright (c) 2003-2013 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -242,5 +242,5 @@ void test()
 BOOST_ASIO_TEST_SUITE
 (
   "buffer",
-  BOOST_ASIO_TEST_CASE(buffer_compile::test)
+  BOOST_ASIO_COMPILE_TEST_CASE(buffer_compile::test)
 )
