@@ -313,6 +313,13 @@ void print_compiler_macros()
   PRINT_MACRO(_FASTMD); 
   PRINT_MACRO(_MAXVL); 
 
+  // clang options:
+  PRINT_MACRO(__clang__); 
+  PRINT_MACRO(__clang_major__);
+  PRINT_MACRO(__clang_minor__);
+  PRINT_MACRO(__clang_version__);
+  PRINT_MACRO(__clang_patchlevel__);
+
   // misc compilers not covered so far:
   PRINT_MACRO(__USLC__);
   PRINT_MACRO(__DECCXX);
@@ -337,6 +344,10 @@ void print_compiler_macros()
   PRINT_MACRO(__CUDACC_VER_MINOR__);
   PRINT_MACRO(__CUDACC_VER_BUILD__);
   PRINT_MACRO(__CUDACC_VER__);
+
+  // Android:
+  PRINT_MACRO(ANDROID);
+  PRINT_MACRO(__ANDROID__);
 }
 
 void print_stdlib_macros()
@@ -970,23 +981,6 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_HAS_STATIC_ASSERT);
    PRINT_MACRO(BOOST_HAS_STDINT_H);
    PRINT_MACRO(BOOST_HAS_STLP_USE_FACET);
-   PRINT_MACRO(BOOST_HAS_TR1_ARRAY);
-   PRINT_MACRO(BOOST_HAS_TR1_BIND);
-   PRINT_MACRO(BOOST_HAS_TR1_COMPLEX_INVERSE_TRIG);
-   PRINT_MACRO(BOOST_HAS_TR1_COMPLEX_OVERLOADS);
-   PRINT_MACRO(BOOST_HAS_TR1_FUNCTION);
-   PRINT_MACRO(BOOST_HAS_TR1_HASH);
-   PRINT_MACRO(BOOST_HAS_TR1_MEM_FN);
-   PRINT_MACRO(BOOST_HAS_TR1_RANDOM);
-   PRINT_MACRO(BOOST_HAS_TR1_REFERENCE_WRAPPER);
-   PRINT_MACRO(BOOST_HAS_TR1_REGEX);
-   PRINT_MACRO(BOOST_HAS_TR1_RESULT_OF);
-   PRINT_MACRO(BOOST_HAS_TR1_SHARED_PTR);
-   PRINT_MACRO(BOOST_HAS_TR1_TUPLE);
-   PRINT_MACRO(BOOST_HAS_TR1_TYPE_TRAITS);
-   PRINT_MACRO(BOOST_HAS_TR1_UNORDERED_MAP);
-   PRINT_MACRO(BOOST_HAS_TR1_UNORDERED_SET);
-   PRINT_MACRO(BOOST_HAS_TR1_UTILITY);
    PRINT_MACRO(BOOST_HAS_TWO_ARG_USE_FACET);
    PRINT_MACRO(BOOST_HAS_UNISTD_H);
    PRINT_MACRO(BOOST_HAS_VARIADIC_TMPL);
@@ -1048,11 +1042,13 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_CXX11_NON_PUBLIC_DEFAULTED_FUNCTIONS);
    PRINT_MACRO(BOOST_NO_CXX11_NULLPTR);
    PRINT_MACRO(BOOST_NO_CXX11_NUMERIC_LIMITS);
+   PRINT_MACRO(BOOST_NO_CXX11_POINTER_TRAITS);
    PRINT_MACRO(BOOST_NO_CXX11_RANGE_BASED_FOR);
    PRINT_MACRO(BOOST_NO_CXX11_RAW_LITERALS);
    PRINT_MACRO(BOOST_NO_CXX11_REF_QUALIFIERS);
    PRINT_MACRO(BOOST_NO_CXX11_RVALUE_REFERENCES);
    PRINT_MACRO(BOOST_NO_CXX11_SCOPED_ENUMS);
+   PRINT_MACRO(BOOST_NO_CXX11_SFINAE_EXPR);
    PRINT_MACRO(BOOST_NO_CXX11_SMART_PTR);
    PRINT_MACRO(BOOST_NO_CXX11_STATIC_ASSERT);
    PRINT_MACRO(BOOST_NO_CXX11_STD_ALIGN);
@@ -1073,7 +1069,16 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_CXX14_HDR_SHARED_MUTEX);
    PRINT_MACRO(BOOST_NO_CXX14_INITIALIZED_LAMBDA_CAPTURES);
    PRINT_MACRO(BOOST_NO_CXX14_RETURN_TYPE_DEDUCTION);
+   PRINT_MACRO(BOOST_NO_CXX14_STD_EXCHANGE);
    PRINT_MACRO(BOOST_NO_CXX14_VARIABLE_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_CXX17_FOLD_EXPRESSIONS);
+   PRINT_MACRO(BOOST_NO_CXX17_INLINE_VARIABLES);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_APPLY);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_INVOKE);
+   PRINT_MACRO(BOOST_NO_CXX17_STRUCTURED_BINDINGS);
+   PRINT_MACRO(BOOST_NO_CXX98_BINDERS);
+   PRINT_MACRO(BOOST_NO_CXX98_FUNCTION_BASE);
+   PRINT_MACRO(BOOST_NO_CXX98_RANDOM_SHUFFLE);
    PRINT_MACRO(BOOST_NO_DEPENDENT_NESTED_DERIVATIONS);
    PRINT_MACRO(BOOST_NO_DEPENDENT_TYPES_IN_TEMPLATE_VALUE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_EXCEPTIONS);
@@ -1103,6 +1108,7 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_CONST);
    PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_PRIVATE_IN_AGGREGATE);
+   PRINT_MACRO(BOOST_NO_RESTRICT_REFERENCES);
    PRINT_MACRO(BOOST_NO_RTTI);
    PRINT_MACRO(BOOST_NO_SFINAE);
    PRINT_MACRO(BOOST_NO_SFINAE_EXPR);
@@ -1133,14 +1139,6 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_USING_TEMPLATE);
    PRINT_MACRO(BOOST_NO_VOID_RETURNS);
 
-
-
-
-
-
-
-
-
    // END GENERATED BLOCK
 
    PRINT_MACRO(BOOST_INTEL);
