@@ -38,16 +38,16 @@ namespace BOOST_PP_CAT(CONTAINER_TYPE, _tests)
         containers[9].insert(pair(key(-1),value(3)));
         containers[9].insert(pair(key(-1),value(3)));
 
-        HASH_NAMESPACE::hash<T> hasher;
+        BOOST_HASH_TEST_NAMESPACE::hash<T> hasher;
 
         for(int i2 = 0; i2 < number_of_containers; ++i2) {
             BOOST_TEST(hasher(containers[i2]) == hasher(containers[i2]));
 
             BOOST_TEST(hasher(containers[i2]) ==
-                    HASH_NAMESPACE::hash_value(containers[i2]));
+                    BOOST_HASH_TEST_NAMESPACE::hash_value(containers[i2]));
 
             BOOST_TEST(hasher(containers[i2])
-                    == HASH_NAMESPACE::hash_range(
+                    == BOOST_HASH_TEST_NAMESPACE::hash_range(
                         containers[i2].begin(), containers[i2].end()));
 
             for(int j2 = i2 + 1; j2 < number_of_containers; ++j2) {
