@@ -19,6 +19,8 @@ namespace BOOST_PP_CAT(CONTAINER_TYPE, _tests)
     template <class T>
     void integer_tests(T* = 0)
     {
+        typedef typename T::value_type value_type;
+
         const int number_of_containers = 11;
         T containers[number_of_containers];
 
@@ -27,27 +29,27 @@ namespace BOOST_PP_CAT(CONTAINER_TYPE, _tests)
                 containers[i].push_back(0);
         }
 
-        containers[5].push_back(1);
-        containers[6].push_back(1);
-        containers[6].push_back(1);
-        containers[7].push_back(-1);
-        containers[8].push_back(-1);
-        containers[8].push_back(-1);
-        containers[9].push_back(1);
-        containers[9].push_back(-1);
-        containers[10].push_back(-1);
-        containers[10].push_back(1);
+        containers[5].push_back(value_type(1));
+        containers[6].push_back(value_type(1));
+        containers[6].push_back(value_type(1));
+        containers[7].push_back(value_type(-1));
+        containers[8].push_back(value_type(-1));
+        containers[8].push_back(value_type(-1));
+        containers[9].push_back(value_type(1));
+        containers[9].push_back(value_type(-1));
+        containers[10].push_back(value_type(-1));
+        containers[10].push_back(value_type(1));
 
-        HASH_NAMESPACE::hash<T> hasher;
+        BOOST_HASH_TEST_NAMESPACE::hash<T> hasher;
 
         for(int i2 = 0; i2 < number_of_containers; ++i2) {
             BOOST_TEST(hasher(containers[i2]) == hasher(containers[i2]));
 
             BOOST_TEST(hasher(containers[i2]) ==
-                    HASH_NAMESPACE::hash_value(containers[i2]));
+                    BOOST_HASH_TEST_NAMESPACE::hash_value(containers[i2]));
 
             BOOST_TEST(hasher(containers[i2])
-                    == HASH_NAMESPACE::hash_range(
+                    == BOOST_HASH_TEST_NAMESPACE::hash_range(
                         containers[i2].begin(), containers[i2].end()));
 
             for(int j2 = i2 + 1; j2 < number_of_containers; ++j2) {
