@@ -33,18 +33,37 @@ public:
       return boost::property_tree::ptree::path_type(str, '/');
     }
 
-    static void get_graphs(const boost::property_tree::ptree& top,
+    void get_graphs(const boost::property_tree::ptree& top,
+                           size_t desired_idx /* or -1 for all */, bool is_root,
                            std::vector<const boost::property_tree::ptree*>& result) {
       using boost::property_tree::ptree;
+      size_t current_idx = 0;
+      bool is_first = is_root;
       BOOST_FOREACH(const ptree::value_type& n, top) {
         if (n.first == "graph") {
-          result.push_back(&n.second);
-          get_graphs(n.second, result);
+          if (current_idx == desired_idx || desired_idx == (size_t)(-1)) {
+            result.push_back(&n.second);
+            if(is_first)
+            {
+              is_first = false;
+              BOOST_FOREACH(const ptree::value_type& attr, n.second) {
+                if (attr.first != "data") 
+                  continue;
+                std::string key = attr.second.get<std::string>(path("<xmlattr>/key"));
+                std::string value = attr.second.get_value("");
+                handle_graph_property(key, value);
+              }
+            }
+            
+            get_graphs(n.second, (size_t)(-1), false, result);
+            if (desired_idx != (size_t)(-1)) break;
+          }
+          ++current_idx;
         }
       }
     }
     
-    void run(std::istream& in)
+    void run(std::istream& in, size_t desired_idx)
     {
       using boost::property_tree::ptree;
       ptree pt;
@@ -65,6 +84,7 @@ public:
         else if (for_ == "port") kind = port_key;
         else if (for_ == "endpoint") kind = endpoint_key;
         else if (for_ == "all") kind = all_key;
+        else if (for_ == "graphml") kind = graphml_key;
         else {BOOST_THROW_EXCEPTION(parse_error("Attribute for is not valid: " + for_));}
         m_keys[id] = kind;
         m_key_name[id] = name;
@@ -74,7 +94,8 @@ public:
       }
       // Search for graphs
       std::vector<const ptree*> graphs;
-      get_graphs(gml, graphs);
+      handle_graph();
+      get_graphs(gml, desired_idx, true, graphs);
       BOOST_FOREACH(const ptree* gr, graphs) {
         // Search for nodes
         BOOST_FOREACH(const ptree::value_type& node, *gr) {
@@ -126,7 +147,8 @@ private:
         hyperedge_key,
         port_key,
         endpoint_key, 
-        all_key
+        all_key,
+        graphml_key
     };
 
     void 
@@ -185,6 +207,22 @@ private:
         }
     }
 
+    void 
+    handle_graph()
+    {
+      std::map<std::string, std::string>::iterator iter;
+      for (iter = m_key_default.begin(); iter != m_key_default.end(); ++iter)
+      {
+        if (m_keys[iter->first] == graph_key)
+          handle_graph_property(iter->first, iter->second);
+      }
+    }
+
+    void handle_graph_property(const std::string& key_id, const std::string& value)
+    {
+      m_g.set_graph_property(m_key_name[key_id], value, m_key_type[key_id]);
+    }
+
     void handle_node_property(const std::string& key_id, const std::string& descriptor, const std::string& value)
     {
       m_g.set_vertex_property(m_key_name[key_id], m_vertex[descriptor], value, m_key_type[key_id]);
@@ -209,9 +247,9 @@ private:
 namespace boost
 {
 void BOOST_GRAPH_DECL
-read_graphml(std::istream& in, mutate_graph& g)
+read_graphml(std::istream& in, mutate_graph& g, size_t desired_idx)
 {    
     graphml_reader reader(g);
-    reader.run(in);
+    reader.run(in, desired_idx);
 }
 }
