@@ -17,7 +17,7 @@
 
 namespace boost { namespace interprocess { namespace test {
 
-#define BOOST_INTERPROCES_CHECK( P )  \
+#define BOOST_INTERPROCESS_CHECK( P )  \
    if(!(P)) do{  assert(P); std::cout << "Failed: " << #P << " file: " << __FILE__ << " line : " << __LINE__ << std::endl; throw boost::interprocess::interprocess_exception(#P);}while(0)
 
 }}}   //namespace boost { namespace interprocess { namespace test {
