@@ -26,6 +26,7 @@
 #  define TEST_REAL_CONCEPT
 #endif
 
+#include <boost/math/tools/test.hpp> // for real_concept
 #include <boost/math/concepts/real_concept.hpp> // for real_concept
 using ::boost::math::concepts::real_concept;
 
@@ -307,10 +308,10 @@ if(std::numeric_limits<RealType>::is_specialized)
 
   // Error tests:
   check_out_of_range<negative_binomial_distribution<RealType> >(20, 0.5);
-  BOOST_CHECK_THROW(negative_binomial_distribution<RealType>(0, 0.5), std::domain_error);
-  BOOST_CHECK_THROW(negative_binomial_distribution<RealType>(-2, 0.5), std::domain_error);
-  BOOST_CHECK_THROW(negative_binomial_distribution<RealType>(20, -0.5), std::domain_error);
-  BOOST_CHECK_THROW(negative_binomial_distribution<RealType>(20, 1.5), std::domain_error);
+  BOOST_MATH_CHECK_THROW(negative_binomial_distribution<RealType>(0, 0.5), std::domain_error);
+  BOOST_MATH_CHECK_THROW(negative_binomial_distribution<RealType>(-2, 0.5), std::domain_error);
+  BOOST_MATH_CHECK_THROW(negative_binomial_distribution<RealType>(20, -0.5), std::domain_error);
+  BOOST_MATH_CHECK_THROW(negative_binomial_distribution<RealType>(20, 1.5), std::domain_error);
 }
  // End of single spot tests using RealType
 
@@ -612,7 +613,7 @@ if(std::numeric_limits<RealType>::is_specialized)
     // Note that these assume that  BOOST_MATH_OVERFLOW_ERROR_POLICY is NOT throw_on_error.
     // #define BOOST_MATH_THROW_ON_OVERFLOW_POLICY ==  throw_on_error would throw here.
     // #define BOOST_MAT_DOMAIN_ERROR_POLICY IS defined throw_on_error,
-    //  so the throw path of error handling is tested below with BOOST_CHECK_THROW tests.
+    //  so the throw path of error handling is tested below with BOOST_MATH_CHECK_THROW tests.
 
     BOOST_CHECK(
     quantile(  // At P == 1 so k failures should be infinite.
@@ -676,55 +677,55 @@ if(std::numeric_limits<RealType>::is_specialized)
   );
 
   // Check that duff arguments throw domain_error:
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   pdf( // Negative successes!
   negative_binomial_distribution<RealType>(static_cast<RealType>(-1), static_cast<RealType>(0.25)),
   static_cast<RealType>(0)), std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   pdf( // Negative success_fraction!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(-0.25)),
   static_cast<RealType>(0)), std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   pdf( // Success_fraction > 1!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(1.25)),
   static_cast<RealType>(0)),
   std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   pdf( // Negative k argument !
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(0.25)),
   static_cast<RealType>(-1)),
   std::domain_error
   );
-  //BOOST_CHECK_THROW(
+  //BOOST_MATH_CHECK_THROW(
   //pdf( // Unlike binomial there is NO limit on k (failures)
   //negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(0.25)),
   //static_cast<RealType>(9)), std::domain_error
   //);
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   cdf(  // Negative k argument !
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(0.25)),
   static_cast<RealType>(-1)),
   std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   cdf( // Negative success_fraction!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(-0.25)),
   static_cast<RealType>(0)), std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   cdf( // Success_fraction > 1!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(1.25)),
   static_cast<RealType>(0)), std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   quantile(  // Negative success_fraction!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(-0.25)),
   static_cast<RealType>(0)), std::domain_error
   );
-  BOOST_CHECK_THROW(
+  BOOST_MATH_CHECK_THROW(
   quantile( // Success_fraction > 1!
   negative_binomial_distribution<RealType>(static_cast<RealType>(8), static_cast<RealType>(1.25)),
   static_cast<RealType>(0)), std::domain_error
@@ -837,7 +838,7 @@ BOOST_AUTO_TEST_CASE( test_main )
    std::cout << "<note>The long double tests have been disabled on this platform "
       "either because the long double overloads of the usual math functions are "
       "not available at all, or because they are too inaccurate for these tests "
-      "to pass.</note>" << std::cout;
+      "to pass.</note>" << std::endl;
 #endif
 
   
