@@ -1,6 +1,6 @@
 /* Boost.MultiIndex test for observer memfuns.
  *
- * Copyright 2003-2004 Joaqun M Lpez Muoz.
+ * Copyright 2003-2013 Joaquin M Lopez Munoz.
  * Distributed under the Boost Software License, Version 1.0.
  * (See accompanying file LICENSE_1_0.txt or copy at
  * http://www.boost.org/LICENSE_1_0.txt)
@@ -8,11 +8,11 @@
  * See http://www.boost.org/libs/multi_index for library home page.
  */
 
-#include <boost/test/included/test_exec_monitor.hpp>
+#include <boost/detail/lightweight_test.hpp>
 #include "test_observers.hpp"
 
-int test_main(int,char *[])
+int main()
 {
   test_observers();
-  return 0;
+  return boost::report_errors();
 }
