@@ -32,6 +32,7 @@
 //  * required only for pointers - optional for objects
 
 #define BOOST_ARCHIVE_SOURCE
+#include <boost/serialization/config.hpp>
 #include <boost/archive/basic_archive.hpp>
 
 namespace boost {
@@ -41,7 +42,7 @@ namespace archive {
 // constants used in archive signature
 //This should never ever change. note that is not an std::string
 // string.
-BOOST_ARCHIVE_DECL(const char *) 
+BOOST_SYMBOL_VISIBLE const char * 
 BOOST_ARCHIVE_SIGNATURE(){
     return "serialization::archive";
 }
@@ -70,11 +71,16 @@ BOOST_ARCHIVE_SIGNATURE(){
 // 8 - Boost 1.44
 //     separated version_type into library_version_type and class_version_type
 //     changed version_type to be stored as 8 bits.
-// 10- fixed base64 output/input. 
+// 10- fixed base64 output/input.
+// 11- not changes
+// 12- improved serialization of collections
+// 13- simplified visibility, removed Borland, removed pfto
+// 14- improved visibility, refactor map/set
+// 15- corrections to optional and collection loading
 
-BOOST_ARCHIVE_DECL(library_version_type)
+BOOST_SYMBOL_VISIBLE library_version_type
 BOOST_ARCHIVE_VERSION(){
-    return library_version_type(10);
+    return library_version_type(15);
 }
 
 } // namespace archive
