@@ -24,17 +24,18 @@ namespace std{
 #endif
 
 #include <boost/integer_traits.hpp>
-#include <boost/serialization/state_saver.hpp>
-#include <boost/serialization/throw_exception.hpp>
-#include <boost/serialization/tracking.hpp>
 
 #define BOOST_ARCHIVE_SOURCE
 // include this to prevent linker errors when the
 // same modules are marked export and import.
 #define BOOST_SERIALIZATION_SOURCE
+#include <boost/serialization/config.hpp>
+
+#include <boost/serialization/state_saver.hpp>
+#include <boost/serialization/throw_exception.hpp>
+#include <boost/serialization/tracking.hpp>
 
 #include <boost/archive/archive_exception.hpp>
-
 #include <boost/archive/detail/decl.hpp>
 #include <boost/archive/basic_archive.hpp>
 #include <boost/archive/detail/basic_iserializer.hpp>
@@ -183,7 +184,6 @@ class basic_iarchive_impl {
         m_archive_library_version(BOOST_ARCHIVE_VERSION()),
         m_flags(flags)
     {}
-    ~basic_iarchive_impl(){}
     void set_library_version(library_version_type archive_library_version){
         m_archive_library_version = archive_library_version;
     }
@@ -228,7 +228,6 @@ class basic_iarchive_impl {
         const basic_pointer_iserializer * (*finder)(
             const boost::serialization::extended_type_info & type
         )
-
     );
 };
 
@@ -252,8 +251,8 @@ basic_iarchive_impl::reset_object_address(
     //    but the code may work anyway.  Naturally, a bad practice on the part
     //    of the programmer but we can't detect it - as above.  So maybe we
     //    can save a few more people from themselves as above.
-    object_id_type i;
-    for(i = m_moveable_objects.recent; i < m_moveable_objects.end; ++i){
+    object_id_type i = m_moveable_objects.recent;
+    for(; i < m_moveable_objects.end; ++i){
         if(old_address == object_id_vector[i].address)
             break;
     }
@@ -418,7 +417,6 @@ basic_iarchive_impl::load_pointer(
     const basic_pointer_iserializer * (*finder)(
         const boost::serialization::extended_type_info & type_
     )
-
 ){
     m_moveable_objects.is_pointer = true;
     serialization::state_saver<bool> w(m_moveable_objects.is_pointer);
@@ -452,10 +450,10 @@ basic_iarchive_impl::load_pointer(
             bpis_ptr = (*finder)(*eti);
         }
         BOOST_ASSERT(NULL != bpis_ptr);
-        class_id_type new_cid = register_type(bpis_ptr->get_basic_serializer());
+        // class_id_type new_cid = register_type(bpis_ptr->get_basic_serializer());
+        BOOST_VERIFY(register_type(bpis_ptr->get_basic_serializer()) == cid);
         int i = cid;
         cobject_id_vector[i].bpis_ptr = bpis_ptr;
-        BOOST_ASSERT(new_cid == cid);
     }
     int i = cid;
     cobject_id & co = cobject_id_vector[i];
@@ -473,6 +471,10 @@ basic_iarchive_impl::load_pointer(
     // save state
     serialization::state_saver<object_id_type> w_start(m_moveable_objects.start);
 
+    // allocate space on the heap for the object - to be constructed later
+    t = bpis_ptr->heap_allocation();
+    BOOST_ASSERT(NULL != t);
+
     if(! tracking){
         bpis_ptr->load_object_ptr(ar, t, co.file_version);
     }
@@ -485,24 +487,23 @@ basic_iarchive_impl::load_pointer(
         m_pending.version = co.file_version;
 
         // predict next object id to be created
-        const unsigned int ui = object_id_vector.size();
+        const size_t ui = object_id_vector.size();
 
         serialization::state_saver<object_id_type> w_end(m_moveable_objects.end);
 
-        // because the following operation could move the items
-        // don't use co after this
+        
         // add to list of serialized objects so that we can properly handle
         // cyclic strucures
         object_id_vector.push_back(aobject(t, cid));
 
+        // remember that that the address of these elements could change
+        // when we make another call so don't use the address
         bpis_ptr->load_object_ptr(
-            ar, 
-            object_id_vector[ui].address, 
-            co.file_version
+            ar,
+            t,
+            m_pending.version
         );
-        t = object_id_vector[ui].address;
         object_id_vector[ui].loaded_as_pointer = true;
-        BOOST_ASSERT(NULL != t);
     }
 
     return bpis_ptr;
@@ -518,28 +519,26 @@ namespace boost {
 namespace archive {
 namespace detail {
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::next_object_pointer(void *t){
     pimpl->next_object_pointer(t);
 }
 
-BOOST_ARCHIVE_DECL(BOOST_PP_EMPTY())
+BOOST_ARCHIVE_DECL
 basic_iarchive::basic_iarchive(unsigned int flags) : 
     pimpl(new basic_iarchive_impl(flags))
 {}
 
-BOOST_ARCHIVE_DECL(BOOST_PP_EMPTY())
+BOOST_ARCHIVE_DECL
 basic_iarchive::~basic_iarchive()
-{
-    delete pimpl;
-}
+{}
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::set_library_version(library_version_type archive_library_version){
     pimpl->set_library_version(archive_library_version);
 }
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::reset_object_address(
     const void * new_address, 
     const void * old_address
@@ -547,7 +546,7 @@ basic_iarchive::reset_object_address(
     pimpl->reset_object_address(new_address, old_address);
 }
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::load_object(
     void *t, 
     const basic_iserializer & bis
@@ -556,7 +555,7 @@ basic_iarchive::load_object(
 }
 
 // load a pointer object
-BOOST_ARCHIVE_DECL(const basic_pointer_iserializer *)
+BOOST_ARCHIVE_DECL const basic_pointer_iserializer *
 basic_iarchive::load_pointer(
     void * &t, 
     const basic_pointer_iserializer * bpis_ptr,
@@ -568,23 +567,23 @@ basic_iarchive::load_pointer(
     return pimpl->load_pointer(*this, t, bpis_ptr, finder);
 }
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::register_basic_serializer(const basic_iserializer & bis){
     pimpl->register_type(bis);
 }
 
-BOOST_ARCHIVE_DECL(void)
+BOOST_ARCHIVE_DECL void
 basic_iarchive::delete_created_pointers()
 {
     pimpl->delete_created_pointers();
 }
 
-BOOST_ARCHIVE_DECL(boost::archive::library_version_type) 
+BOOST_ARCHIVE_DECL boost::archive::library_version_type
 basic_iarchive::get_library_version() const{
     return pimpl->m_archive_library_version;
 }
 
-BOOST_ARCHIVE_DECL(unsigned int) 
+BOOST_ARCHIVE_DECL unsigned int
 basic_iarchive::get_flags() const{
     return pimpl->m_flags;
 }
