@@ -17,9 +17,12 @@
 
 #include <boost/core/no_exceptions_support.hpp>
 
-#include <boost/serialization/singleton.hpp>
-
+// it marks our code with proper attributes as being exported when
+// we're compiling it while marking it import when just the headers
+// is being included.
 #define BOOST_SERIALIZATION_SOURCE
+#include <boost/serialization/config.hpp>
+#include <boost/serialization/singleton.hpp>
 #include <boost/serialization/extended_type_info_typeid.hpp>
 
 namespace boost { 
@@ -44,7 +47,7 @@ typedef std::multiset<
     type_compare
 > tkmap;
     
-BOOST_SERIALIZATION_DECL(bool) 
+BOOST_SERIALIZATION_DECL bool
 extended_type_info_typeid_0::is_less_than(
     const boost::serialization::extended_type_info & rhs
 ) const {
@@ -56,7 +59,7 @@ extended_type_info_typeid_0::is_less_than(
     );
 }
 
-BOOST_SERIALIZATION_DECL(bool) 
+BOOST_SERIALIZATION_DECL bool
 extended_type_info_typeid_0::is_equal(
     const boost::serialization::extended_type_info & rhs
 ) const {
@@ -70,7 +73,7 @@ extended_type_info_typeid_0::is_equal(
     ;
 }
 
-BOOST_SERIALIZATION_DECL(BOOST_PP_EMPTY())
+BOOST_SERIALIZATION_DECL
 extended_type_info_typeid_0::extended_type_info_typeid_0(
     const char * key
 ) :
@@ -78,20 +81,21 @@ extended_type_info_typeid_0::extended_type_info_typeid_0(
     m_ti(NULL)
 {}
 
-BOOST_SERIALIZATION_DECL(BOOST_PP_EMPTY())
+BOOST_SERIALIZATION_DECL
 extended_type_info_typeid_0::~extended_type_info_typeid_0()
 {}
 
-BOOST_SERIALIZATION_DECL(void) 
+BOOST_SERIALIZATION_DECL void 
 extended_type_info_typeid_0::type_register(const std::type_info & ti){
     m_ti = & ti;
     singleton<tkmap>::get_mutable_instance().insert(this);
 }
 
-BOOST_SERIALIZATION_DECL(void) 
+BOOST_SERIALIZATION_DECL void 
 extended_type_info_typeid_0::type_unregister()
 {
     if(NULL != m_ti){
+        BOOST_ASSERT(! singleton<tkmap>::is_destroyed());
         if(! singleton<tkmap>::is_destroyed()){
             tkmap & x = singleton<tkmap>::get_mutable_instance();
             tkmap::iterator start = x.lower_bound(this);
@@ -144,7 +148,7 @@ public:
 #  pragma warning(pop)
 #endif
 
-BOOST_SERIALIZATION_DECL(const extended_type_info *)
+BOOST_SERIALIZATION_DECL const extended_type_info *
 extended_type_info_typeid_0::get_extended_type_info(
     const std::type_info & ti
 ) const {
