@@ -9,13 +9,7 @@
 //  See http://www.boost.org for updates, documentation, and revision history.
 
 #include <boost/serialization/export.hpp>
+
 #include "polymorphic_base.hpp"
 
 BOOST_CLASS_EXPORT_IMPLEMENT(polymorphic_base)
-
-const char * polymorphic_base::get_key() const{
-    return
-        boost::serialization::type_info_implementation<
-            polymorphic_base
-        >::type::get_const_instance().get_key();
-}
