@@ -2,7 +2,7 @@
 #define POLYMORPHIC_DERIVED2_HPP
 
 // MS compatible compilers support #pragma once
-#if defined(_MSC_VER) && (_MSC_VER >= 1020)
+#if defined(_MSC_VER)
 # pragma once
 #endif
 
@@ -16,27 +16,27 @@
 
 //  See http://www.boost.org for updates, documentation, and revision history.
 
+#include <boost/config.hpp>
+
 #include <boost/serialization/access.hpp>
 #include <boost/serialization/nvp.hpp>
 #include <boost/serialization/base_object.hpp>
 #include <boost/serialization/type_info_implementation.hpp>
 #include <boost/serialization/extended_type_info_typeid.hpp>
 
-#include <boost/preprocessor/empty.hpp>
-
 #include "polymorphic_base.hpp"
 
-#include "test_decl.hpp"
-
 #if defined(POLYMORPHIC_DERIVED2_IMPORT)
-    #define DLL_DECL IMPORT_DECL
+    #define POLYMORPHIC_DERIVED2_DLL_DECL BOOST_SYMBOL_IMPORT
+    #pragma message ("polymorphic_derived2 imported")
 #elif defined(POLYMORPHIC_DERIVED2_EXPORT)
-    #define DLL_DECL EXPORT_DECL
+    #define POLYMORPHIC_DERIVED2_DLL_DECL BOOST_SYMBOL_EXPORT
+    #pragma message ("polymorphic_derived2 exported")
 #else
-    #define DLL_DECL(x)
+    #define POLYMORPHIC_DERIVED2_DLL_DECL
 #endif
 
-class DLL_DECL(BOOST_PP_EMPTY()) polymorphic_derived2 : 
+class POLYMORPHIC_DERIVED2_DLL_DECL polymorphic_derived2 :
     public polymorphic_base
 {
     friend class boost::serialization::access;
@@ -63,7 +63,5 @@ BOOST_CLASS_TYPE_INFO(
     boost::serialization::extended_type_info_typeid<polymorphic_derived2>
 )
 
-#undef DLL_DECL
-
 #endif // POLYMORPHIC_DERIVED2_HPP
 
