@@ -58,13 +58,24 @@ int main()
         boost::shared_ptr< int > pi = boost::make_shared< int >();
 
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
+
         BOOST_TEST( *pi == 0 );
     }
 
+    {
+        boost::shared_ptr< int > pi = boost::make_shared_noinit< int >();
+
+        BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
+    }
+
     {
         boost::shared_ptr< int > pi = boost::make_shared< int >( 5 );
 
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
+
         BOOST_TEST( *pi == 5 );
     }
 
@@ -76,6 +87,21 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
+        BOOST_TEST( pi->v == 0 );
+
+        pi.reset();
+
+        BOOST_TEST( X::instances == 0 );
+    }
+
+    {
+        boost::shared_ptr< X > pi = boost::make_shared_noinit< X >();
+        boost::weak_ptr<X> wp( pi );
+
+        BOOST_TEST( X::instances == 1 );
+        BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 0 );
 
         pi.reset();
@@ -89,6 +115,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1 );
 
         pi.reset();
@@ -102,6 +129,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2 );
 
         pi.reset();
@@ -115,6 +143,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3 );
 
         pi.reset();
@@ -128,6 +157,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4 );
 
         pi.reset();
@@ -141,6 +171,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4+5 );
 
         pi.reset();
@@ -154,6 +185,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4+5+6 );
 
         pi.reset();
@@ -167,6 +199,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4+5+6+7 );
 
         pi.reset();
@@ -180,6 +213,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4+5+6+7+8 );
 
         pi.reset();
@@ -193,6 +227,7 @@ int main()
 
         BOOST_TEST( X::instances == 1 );
         BOOST_TEST( pi.get() != 0 );
+        BOOST_TEST( pi.use_count() == 1 );
         BOOST_TEST( pi->v == 1+2+3+4+5+6+7+8+9 );
 
         pi.reset();
