@@ -25,7 +25,7 @@ BOOST_DECL_TRANSFORM_TEST(add_reference_test_10, ::tt::add_reference, const*, co
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_11, ::tt::add_reference, volatile*, volatile*&)
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_12, ::tt::add_reference, const[2][3], const (&)[2][3])
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_13, ::tt::add_reference, (&)[2], (&)[2])
-#ifndef BOOST_NO_RVALUE_REFERENCES
+#ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_5a, ::tt::add_reference, const &&, const&&)
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_6a, ::tt::add_reference, &&, &&)
 BOOST_DECL_TRANSFORM_TEST(add_reference_test_13a, ::tt::add_reference, (&&)[2], (&&)[2])
@@ -46,12 +46,17 @@ TT_TEST_BEGIN(add_reference)
    add_reference_test_11();
    add_reference_test_12();
    add_reference_test_13();
-#ifndef BOOST_NO_RVALUE_REFERENCES
+#ifndef BOOST_NO_CXX11_RVALUE_REFERENCES
    add_reference_test_5a();
    add_reference_test_6a();
    add_reference_test_13a();
 #endif
 
+   BOOST_CHECK_TYPE(tt::add_reference<void>::type, void);
+   BOOST_CHECK_TYPE(tt::add_reference<const void>::type, const void);
+   BOOST_CHECK_TYPE(tt::add_reference<const volatile void>::type, const volatile void);
+   BOOST_CHECK_TYPE(tt::add_reference<volatile void>::type, volatile void);
+
 TT_TEST_END
 
 
