@@ -3,10 +3,12 @@
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
+// clang-format off
 #include "../helpers/prefix.hpp"
 #include <boost/unordered_set.hpp>
 #include <boost/unordered_map.hpp>
 #include "../helpers/postfix.hpp"
+// clang-format on
 
 #include "../helpers/test.hpp"
 #include <boost/limits.hpp>
@@ -14,16 +16,14 @@
 
 #if defined(BOOST_MSVC)
 #pragma warning(push)
-#pragma warning(disable:4127) // conditional expression is constant
+#pragma warning(disable : 4127) // conditional expression is constant
 #endif
 
-namespace load_factor_tests
-{
+namespace load_factor_tests {
 
 test::seed_t initialize_seed(783656);
 
-template <class X>
-void set_load_factor_tests(X*)
+template <class X> void set_load_factor_tests(X*)
 {
     X x;
 
@@ -32,8 +32,10 @@ void set_load_factor_tests(X*)
 
     // A valid implementation could fail these tests, but I think they're
     // reasonable.
-    x.max_load_factor(2.0); BOOST_TEST(x.max_load_factor() == 2.0);
-    x.max_load_factor(0.5); BOOST_TEST(x.max_load_factor() == 0.5);
+    x.max_load_factor(2.0);
+    BOOST_TEST(x.max_load_factor() == 2.0);
+    x.max_load_factor(0.5);
+    BOOST_TEST(x.max_load_factor() == 0.5);
 }
 
 template <class X>
@@ -45,13 +47,15 @@ void insert_test(X*, float mlf, test::random_generator generator)
 
     test::random_values<X> values(1000, generator);
 
-    for(BOOST_DEDUCED_TYPENAME test::random_values<X>::const_iterator
-            it = values.begin(), end = values.end(); it != end; ++it)
-    {
+    for (BOOST_DEDUCED_TYPENAME test::random_values<X>::const_iterator
+             it = values.begin(),
+             end = values.end();
+         it != end; ++it) {
         BOOST_DEDUCED_TYPENAME X::size_type old_size = x.size(),
-                 old_bucket_count = x.bucket_count();
+                                            old_bucket_count = x.bucket_count();
         x.insert(*it);
-        if(static_cast<double>(old_size + 1) <= b * static_cast<double>(old_bucket_count))
+        if (static_cast<double>(old_size + 1) <=
+            b * static_cast<double>(old_bucket_count))
             BOOST_TEST(x.bucket_count() == old_bucket_count);
     }
 }
@@ -63,12 +67,10 @@ void load_factor_insert_tests(X* ptr, test::random_generator generator)
     insert_test(ptr, 0.1f, generator);
     insert_test(ptr, 100.0f, generator);
 
-    insert_test(ptr, (std::numeric_limits<float>::min)(),
-        generator);
+    insert_test(ptr, (std::numeric_limits<float>::min)(), generator);
 
-    if(std::numeric_limits<float>::has_infinity)
-        insert_test(ptr, std::numeric_limits<float>::infinity(),
-            generator);
+    if (std::numeric_limits<float>::has_infinity)
+        insert_test(ptr, std::numeric_limits<float>::infinity(), generator);
 }
 
 boost::unordered_set<int>* int_set_ptr;
@@ -81,19 +83,16 @@ using test::generate_collisions;
 using test::limited_range;
 
 UNORDERED_TEST(set_load_factor_tests,
-    ((int_set_ptr)(int_multiset_ptr)(int_map_ptr)(int_multimap_ptr))
-)
+    ((int_set_ptr)(int_multiset_ptr)(int_map_ptr)(int_multimap_ptr)))
 
 UNORDERED_TEST(load_factor_insert_tests,
-    ((int_set_ptr)(int_multiset_ptr)(int_map_ptr)(int_multimap_ptr))
-    ((default_generator)(generate_collisions)(limited_range))
-)
-
+    ((int_set_ptr)(int_multiset_ptr)(int_map_ptr)(int_multimap_ptr))(
+                   (default_generator)(generate_collisions)(limited_range)))
 }
 
 RUN_TESTS()
 
 #if defined(BOOST_MSVC)
 #pragma warning(pop)
-#pragma warning(disable:4127) // conditional expression is constant
+#pragma warning(disable : 4127) // conditional expression is constant
 #endif
