@@ -1,7 +1,7 @@
 
 // boostdep - a tool to generate Boost dependency reports
 //
-// Copyright 2014, 2015, 2016 Peter Dimov
+// Copyright 2014-2017 Peter Dimov
 //
 // Distributed under the Boost Software License, Version 1.0.
 // See accompanying file LICENSE_1_0.txt or copy at
@@ -46,13 +46,14 @@ static void scan_module_headers( fs::path const & path )
 
         for( ; it != last; ++it )
         {
-            fs::directory_entry const & e = *it;
+            if( it->status().type() == fs::directory_file )
+            {
+                continue;
+            }
 
-            std::string p2 = e.path().generic_string();
+            std::string p2 = it->path().generic_string();
             p2 = p2.substr( n+1 );
 
-            // std::cout << module << ": " << p2 << std::endl;
-
             s_header_map[ p2 ] = module;
             s_module_headers[ module ].insert( p2 );
         }
@@ -190,7 +191,42 @@ static fs::path module_build_path( std::string module )
     return fs::path( "libs" ) / module / "build";
 }
 
-static void scan_module_dependencies( std::string const & module, module_primary_actions & actions, bool track_sources, bool include_self )
+static fs::path module_test_path( std::string module )
+{
+    std::replace( module.begin(), module.end(), '~', '/' );
+    return fs::path( "libs" ) / module / "test";
+}
+
+static void scan_module_path( fs::path const & dir, bool remove_prefix, std::map< std::string, std::set< std::string > > & deps, std::map< std::string, std::set< std::string > > & from )
+{
+    size_t n = dir.generic_string().size();
+
+    if( fs::exists( dir ) )
+    {
+        fs::recursive_directory_iterator it( dir ), last;
+
+        for( ; it != last; ++it )
+        {
+            if( it->status().type() == fs::directory_file )
+            {
+                continue;
+            }
+
+            std::string header = it->path().generic_string();
+
+            if( remove_prefix )
+            {
+                header = header.substr( n+1 );
+            }
+
+            fs::ifstream is( it->path() );
+
+            scan_header_dependencies( header, is, deps, from );
+        }
+    }
+}
+
+static void scan_module_dependencies( std::string const & module, module_primary_actions & actions, bool track_sources, bool track_tests, bool include_self )
 {
     // module -> [ header, header... ]
     std::map< std::string, std::set< std::string > > deps;
@@ -198,40 +234,16 @@ static void scan_module_dependencies( std::string const & module, module_primary
     // header -> included from [ header, header... ]
     std::map< std::string, std::set< std::string > > from;
 
-    {
-        fs::path dir = module_include_path( module );
-        size_t n = dir.generic_string().size();
-
-        fs::recursive_directory_iterator it( dir ), last;
-
-        for( ; it != last; ++it )
-        {
-            std::string header = it->path().generic_string().substr( n+1 );
-
-            fs::ifstream is( it->path() );
-
-            scan_header_dependencies( header, is, deps, from );
-        }
-    }
+    scan_module_path( module_include_path( module ), true, deps, from );
 
     if( track_sources )
     {
-        fs::path dir = module_source_path( module );
-        size_t n = dir.generic_string().size();
+        scan_module_path( module_source_path( module ), false, deps, from );
+    }
 
-        if( fs::exists( dir ) )
-        {
-            fs::recursive_directory_iterator it( dir ), last;
-
-            for( ; it != last; ++it )
-            {
-                std::string header = it->path().generic_string().substr( n+1 );
-
-                fs::ifstream is( it->path() );
-
-                scan_header_dependencies( header, is, deps, from );
-            }
-        }
+    if( track_tests )
+    {
+        scan_module_path( module_test_path( module ), false, deps, from );
     }
 
     actions.heading( module );
@@ -318,20 +330,20 @@ struct build_mdmap_actions: public module_primary_actions
     }
 };
 
-static void build_module_dependency_map( bool track_sources )
+static void build_module_dependency_map( bool track_sources, bool track_tests )
 {
     for( std::set< std::string >::iterator i = s_modules.begin(); i != s_modules.end(); ++i )
     {
         build_mdmap_actions actions;
-        scan_module_dependencies( *i, actions, track_sources, true );
+        scan_module_dependencies( *i, actions, track_sources, track_tests, true );
     }
 }
 
-static void output_module_primary_report( std::string const & module, module_primary_actions & actions, bool track_sources )
+static void output_module_primary_report( std::string const & module, module_primary_actions & actions, bool track_sources, bool track_tests )
 {
     try
     {
-        scan_module_dependencies( module, actions, track_sources, false );
+        scan_module_dependencies( module, actions, track_sources, track_tests, false );
     }
     catch( fs::filesystem_error const & x )
     {
@@ -357,12 +369,10 @@ static void exclude( std::set< std::string > & x, std::set< std::string > const
     }
 }
 
-static void output_module_secondary_report( std::string const & module, module_secondary_actions & actions )
+static void output_module_secondary_report( std::string const & module, std::set< std::string> deps, module_secondary_actions & actions )
 {
     actions.heading( module );
 
-    std::set< std::string > deps = s_module_deps[ module ];
-
     deps.insert( module );
 
     // build transitive closure
@@ -405,6 +415,11 @@ static void output_module_secondary_report( std::string const & module, module_s
     }
 }
 
+static void output_module_secondary_report( std::string const & module, module_secondary_actions & actions )
+{
+    output_module_secondary_report( module, s_module_deps[ module ], actions );
+}
+
 struct header_inclusion_actions
 {
     virtual void heading( std::string const & header, std::string const & module ) = 0;
@@ -512,17 +527,17 @@ struct module_primary_html_actions: public module_primary_actions
     }
 };
 
-static void output_module_primary_report( std::string const & module, bool html, bool track_sources )
+static void output_module_primary_report( std::string const & module, bool html, bool track_sources, bool track_tests )
 {
     if( html )
     {
         module_primary_html_actions actions;
-        output_module_primary_report( module, actions, track_sources );
+        output_module_primary_report( module, actions, track_sources, track_tests );
     }
     else
     {
         module_primary_txt_actions actions;
-        output_module_primary_report( module, actions, track_sources );
+        output_module_primary_report( module, actions, track_sources, track_tests );
     }
 }
 
@@ -1300,13 +1315,13 @@ static void output_html_footer( std::string const & footer )
     std::cout << "</html>\n";
 }
 
-static void enable_secondary( bool & secondary, bool track_sources )
+static void enable_secondary( bool & secondary, bool track_sources, bool track_tests )
 {
     if( !secondary )
     {
         try
         {
-            build_module_dependency_map( track_sources );
+            build_module_dependency_map( track_sources, track_tests );
         }
         catch( fs::filesystem_error const & x )
         {
@@ -1610,11 +1625,39 @@ struct module_subset_actions
     virtual void from_path( std::vector<std::string> const & path ) = 0;
 };
 
-static void output_module_subset_report( std::string const & module, module_subset_actions & actions )
+static void add_module_headers( fs::path const & dir, std::set<std::string> & headers )
+{
+    if( fs::exists( dir ) )
+    {
+        fs::recursive_directory_iterator it( dir ), last;
+
+        for( ; it != last; ++it )
+        {
+            if( it->status().type() == fs::directory_file )
+            {
+                continue;
+            }
+
+            headers.insert( it->path().generic_string() );
+        }
+    }
+}
+
+static void output_module_subset_report( std::string const & module, bool track_sources, bool track_tests, module_subset_actions & actions )
 {
     // build header closure
 
-    std::set<std::string> const & headers = s_module_headers[ module ];
+    std::set<std::string> headers = s_module_headers[ module ];
+
+    if( track_sources )
+    {
+        add_module_headers( module_source_path( module ), headers );
+    }
+
+    if( track_tests )
+    {
+        add_module_headers( module_test_path( module ), headers );
+    }
 
     // header -> (header)*
     std::map< std::string, std::set<std::string> > inc2;
@@ -1784,20 +1827,316 @@ struct module_subset_html_actions: public module_subset_actions
     }
 };
 
-static void output_module_subset_report( std::string const & module, bool html )
+static void output_module_subset_report( std::string const & module, bool track_sources, bool track_tests, bool html )
 {
     if( html )
     {
         module_subset_html_actions actions;
-        output_module_subset_report( module, actions );
+        output_module_subset_report( module, track_sources, track_tests, actions );
     }
     else
     {
         module_subset_txt_actions actions;
-        output_module_subset_report( module, actions );
+        output_module_subset_report( module, track_sources, track_tests, actions );
     }
 }
 
+// --list-exceptions
+
+static void list_exceptions()
+{
+    std::string lm;
+
+    for( std::map< std::string, std::set<std::string> >::const_iterator i = s_module_headers.begin(); i != s_module_headers.end(); ++i )
+    {
+        std::string module = i->first;
+
+        std::replace( module.begin(), module.end(), '~', '/' );
+
+        std::string const prefix = "boost/" + module;
+        size_t const n = prefix.size();
+
+        for( std::set< std::string >::const_iterator j = i->second.begin(); j != i->second.end(); ++j )
+        {
+            std::string const & header = *j;
+
+            if( header.substr( 0, n+1 ) != prefix + '/' && header != prefix + ".hpp" )
+            {
+                if( lm != module )
+                {
+                    std::cout << module << ":\n";
+                    lm = module;
+                }
+
+                std::cout << "  " << header << '\n';
+            }
+        }
+    }
+}
+
+// --test
+
+struct module_test_primary_actions: public module_primary_actions
+{
+    std::set< std::string > & m_;
+
+    module_test_primary_actions( std::set< std::string > & m ): m_( m )
+    {
+    }
+
+    void heading( std::string const & module )
+    {
+        std::cout << "Test dependencies for " << module << ":\n\n";
+    }
+
+    void module_start( std::string const & module )
+    {
+        std::cout << module << "\n";
+        m_.insert( module );
+    }
+
+    void module_end( std::string const & /*module*/ )
+    {
+    }
+
+    void header_start( std::string const & /*header*/ )
+    {
+    }
+
+    void header_end( std::string const & /*header*/ )
+    {
+    }
+
+    void from_header( std::string const & /*header*/ )
+    {
+    }
+};
+
+struct module_test_secondary_actions: public module_secondary_actions
+{
+    std::set< std::string > & m_;
+    std::string m2_;
+
+    module_test_secondary_actions( std::set< std::string > & m ): m_( m )
+    {
+    }
+
+    void heading( std::string const & /*module*/ )
+    {
+    }
+
+    void module_start( std::string const & module )
+    {
+        m2_ = module;
+    }
+
+    void module_end( std::string const & /*module*/ )
+    {
+    }
+
+    void module_adds( std::string const & module )
+    {
+        if( m_.count( module ) == 0 )
+        {
+            std::cout << module << " (from " << m2_ << ")\n";
+            m_.insert( module );
+        }
+    }
+};
+
+static void output_module_test_report( std::string const & module )
+{
+    std::set< std::string > m;
+
+    module_test_primary_actions a1( m );
+    output_module_primary_report( module, a1, true, true );
+
+    std::cout << "\n";
+
+    bool secondary = false;
+    enable_secondary( secondary, true, false );
+
+    std::set< std::string > m2( m );
+    m2.insert( module );
+
+    module_test_secondary_actions a2( m2 );
+
+    output_module_secondary_report( module, m, a2 );
+}
+
+// --cmake
+
+struct module_cmake_primary_actions: public module_primary_actions
+{
+    std::set< std::string > & m_;
+
+    module_cmake_primary_actions( std::set< std::string > & m ): m_( m )
+    {
+    }
+
+    void heading( std::string const & )
+    {
+    }
+
+    void module_start( std::string const & module )
+    {
+        m_.insert( module );
+    }
+
+    void module_end( std::string const & /*module*/ )
+    {
+    }
+
+    void header_start( std::string const & /*header*/ )
+    {
+    }
+
+    void header_end( std::string const & /*header*/ )
+    {
+    }
+
+    void from_header( std::string const & /*header*/ )
+    {
+    }
+};
+
+static std::string module_cmake_package( std::string module )
+{
+    std::replace( module.begin(), module.end(), '~', '_' );
+    return "boost_" + module;
+}
+
+static std::string module_cmake_target( std::string module )
+{
+    std::replace( module.begin(), module.end(), '~', '_' );
+    return "boost::" + module;
+}
+
+static void output_module_cmake_report( std::string module )
+{
+    std::replace( module.begin(), module.end(), '/', '~' );
+
+    std::cout << "# Generated file. Do not edit.\n\n";
+
+    std::set< std::string > m1;
+
+    module_cmake_primary_actions a1( m1 );
+    output_module_primary_report( module, a1, false, false );
+
+    if( !fs::exists( module_source_path( module ) ) )
+    {
+        for( std::set< std::string >::const_iterator i = m1.begin(); i != m1.end(); ++i )
+        {
+            std::cout << "boost_declare_dependency(" << module_cmake_package( *i ) << " INTERFACE " << module_cmake_target( *i ) << ")\n";
+        }
+    }
+    else
+    {
+        std::set< std::string > m2;
+
+        module_cmake_primary_actions a2( m2 );
+        output_module_primary_report( module, a2, true, false );
+
+        for( std::set< std::string >::const_iterator i = m1.begin(); i != m1.end(); ++i )
+        {
+            m2.erase( *i );
+            std::cout << "boost_declare_dependency(" << module_cmake_package( *i ) << " PUBLIC " << module_cmake_target( *i ) << ")\n";
+        }
+
+        std::cout << "\n";
+
+        for( std::set< std::string >::const_iterator i = m2.begin(); i != m2.end(); ++i )
+        {
+            std::cout << "boost_declare_dependency(" << module_cmake_package( *i ) << " PRIVATE " << module_cmake_target( *i ) << ")\n";
+        }
+    }
+}
+
+// --list-missing-headers
+
+struct missing_header_actions: public module_primary_actions
+{
+    std::string module_, module2_;
+
+    void heading( std::string const & module )
+    {
+        module_ = module;
+    }
+
+    void module_start( std::string const & module )
+    {
+        module2_ = module;
+    }
+
+    void module_end( std::string const & /*module*/ )
+    {
+    }
+
+    void header_start( std::string const & header )
+    {
+        if( module2_ == "(unknown)" )
+        {
+            if( !module_.empty() )
+            {
+                std::cout << module_ << ":\n";
+                module_.clear();
+            }
+
+            std::cout << "    <" << header << ">\n";
+        }
+    }
+
+    void header_end( std::string const & /*header*/ )
+    {
+    }
+
+    void from_header( std::string const & header )
+    {
+        if( module2_ == "(unknown)" )
+        {
+            std::cout << "        from <" << header << ">\n";
+        }
+    }
+};
+
+static void list_missing_headers( std::string const & module )
+{
+    missing_header_actions a;
+    output_module_primary_report( module, a, false, false );
+}
+
+static void list_missing_headers()
+{
+    for( std::set< std::string >::const_iterator i = s_modules.begin(); i != s_modules.end(); ++i )
+    {
+        list_missing_headers( *i );
+    }
+}
+
+//
+
+static bool find_boost_root()
+{
+    for( int i = 0; i < 32; ++i )
+    {
+        if( fs::exists( "Jamroot" ) )
+        {
+            return true;
+        }
+
+        fs::path p = fs::current_path();
+
+        if( p == p.root_path() )
+        {
+            return false;
+        }
+
+        fs::current_path( p.parent_path() );
+    }
+
+    return false;
+}
+
 int main( int argc, char const* argv[] )
 {
     if( argc < 2 )
@@ -1808,7 +2147,9 @@ int main( int argc, char const* argv[] )
             "\n"
             "    boostdep --list-modules\n"
             "    boostdep --list-buildable\n"
-            "    boostdep [--track-sources] --list-dependencies\n"
+            "    boostdep [--track-sources] [--track-tests] --list-dependencies\n"
+            "    boostdep --list-exceptions\n"
+            "    boostdep --list-missing-headers\n"
             "\n"
             "    boostdep [options] --module-overview\n"
             "    boostdep [options] --module-levels\n"
@@ -1819,12 +2160,21 @@ int main( int argc, char const* argv[] )
             "    boostdep [options] --reverse <module>\n"
             "    boostdep [options] --subset <module>\n"
             "    boostdep [options] [--header] <header>\n"
+            "    boostdep --test <module>\n"
+            "    boostdep --cmake <module>\n"
             "\n"
-            "    [options]: [--track-sources] [--title <title>] [--footer <footer>] [--html]\n";
+            "    [options]: [--[no-]track-sources] [--[no-]track-tests]\n"
+            "               [--title <title>] [--footer <footer>] [--html]\n";
 
         return -1;
     }
 
+    if( !find_boost_root() )
+    {
+        std::cerr << "boostdep: Could not find Boost root.\n";
+        return -2;
+    }
+
     try
     {
         build_header_map();
@@ -1837,6 +2187,7 @@ int main( int argc, char const* argv[] )
     bool html = false;
     bool secondary = false;
     bool track_sources = false;
+    bool track_tests = false;
 
     std::string title = "Boost Dependency Report";
     std::string footer;
@@ -1879,18 +2230,30 @@ int main( int argc, char const* argv[] )
         {
             track_sources = true;
         }
+        else if( option == "--no-track-sources" )
+        {
+            track_sources = false;
+        }
+        else if( option == "--track-tests" )
+        {
+            track_tests = true;
+        }
+        else if( option == "--no-track-tests" )
+        {
+            track_tests = false;
+        }
         else if( option == "--primary" )
         {
             if( i + 1 < argc )
             {
-                output_module_primary_report( argv[ ++i ], html, track_sources );
+                output_module_primary_report( argv[ ++i ], html, track_sources, track_tests );
             }
         }
         else if( option == "--secondary" )
         {
             if( i + 1 < argc )
             {
-                enable_secondary( secondary, track_sources );
+                enable_secondary( secondary, track_sources, track_tests );
                 output_module_secondary_report( argv[ ++i ], html );
             }
         }
@@ -1898,7 +2261,7 @@ int main( int argc, char const* argv[] )
         {
             if( i + 1 < argc )
             {
-                enable_secondary( secondary, track_sources );
+                enable_secondary( secondary, track_sources, track_tests );
                 output_module_reverse_report( argv[ ++i ], html );
             }
         }
@@ -1906,7 +2269,7 @@ int main( int argc, char const* argv[] )
         {
             if( i + 1 < argc )
             {
-                enable_secondary( secondary, track_sources );
+                enable_secondary( secondary, track_sources, track_tests );
                 output_header_report( argv[ ++i ], html );
             }
         }
@@ -1914,37 +2277,59 @@ int main( int argc, char const* argv[] )
         {
             if( i + 1 < argc )
             {
-                enable_secondary( secondary, track_sources );
-                output_module_subset_report( argv[ ++i ], html );
+                enable_secondary( secondary, track_sources, track_tests );
+                output_module_subset_report( argv[ ++i ], track_sources, track_tests, html );
+            }
+        }
+        else if( option == "--test" )
+        {
+            if( i + 1 < argc )
+            {
+                output_module_test_report( argv[ ++i ] );
+            }
+        }
+        else if( option == "--cmake" )
+        {
+            if( i + 1 < argc )
+            {
+                output_module_cmake_report( argv[ ++i ] );
             }
         }
         else if( option == "--module-levels" )
         {
-            enable_secondary( secondary, track_sources );
+            enable_secondary( secondary, track_sources, track_tests );
             output_module_level_report( html );
         }
         else if( option == "--module-overview" )
         {
-            enable_secondary( secondary, track_sources );
+            enable_secondary( secondary, track_sources, track_tests );
             output_module_overview_report( html );
         }
         else if( option == "--module-weights" )
         {
-            enable_secondary( secondary, track_sources );
+            enable_secondary( secondary, track_sources, track_tests );
             output_module_weight_report( html );
         }
         else if( option == "--list-dependencies" )
         {
-            enable_secondary( secondary, track_sources );
+            enable_secondary( secondary, track_sources, track_tests );
             list_dependencies();
         }
+        else if( option == "--list-exceptions" )
+        {
+            list_exceptions();
+        }
+        else if( option == "--list-missing-headers" )
+        {
+            list_missing_headers();
+        }
         else if( s_modules.count( option ) )
         {
-            output_module_primary_report( option, html, track_sources );
+            output_module_primary_report( option, html, track_sources, track_tests );
         }
         else if( s_header_map.count( option ) )
         {
-            enable_secondary( secondary, track_sources );
+            enable_secondary( secondary, track_sources, track_tests );
             output_header_report( option, html );
         }
         else
