@@ -65,7 +65,7 @@ namespace quickbook
         }
         
         std::string add_anchor(quickbook::state& state,
-                boost::string_ref id,
+                quickbook::string_view id,
                 id_category::categories category =
                     id_category::explicit_anchor_id)
         {
@@ -127,6 +127,10 @@ namespace quickbook
         return qbk_version_n >= lower && qbk_version_n < upper;
     }
 
+    bool quickbook_strict::is_strict_checking() const {
+        return state.strict_mode;
+    }
+
     void explicit_list_action(quickbook::state&, value);
     void header_action(quickbook::state&, value);
     void begin_section_action(quickbook::state&, value);
@@ -536,10 +540,12 @@ namespace quickbook
 
         if (saved_conditional)
         {
-            boost::string_ref macro1 = values.consume().get_quickbook();
+            bool positive = values.consume().get_quickbook().empty();
+            quickbook::string_view macro1 = values.consume().get_quickbook();
             std::string macro(macro1.begin(), macro1.end());
 
-            state.conditional = find(state.macro, macro.c_str());
+            state.conditional =
+                (bool)find(state.macro, macro.c_str()) == positive;
 
             if (!state.conditional) {
                 state.push_output();
@@ -760,7 +766,7 @@ namespace quickbook
         int code_tag = code_block.get_tag();
 
         value_consumer values = code_block;
-        boost::string_ref code_value = values.consume().get_quickbook();
+        quickbook::string_view code_value = values.consume().get_quickbook();
         values.finish();
 
         bool inline_code = code_tag == code_tags::inline_code ||
@@ -870,8 +876,8 @@ namespace quickbook
             detail::print_string(v.get_encoded(), out);
         }
         else {
-            boost::string_ref value = v.get_quickbook();
-            for(boost::string_ref::const_iterator
+            quickbook::string_view value = v.get_quickbook();
+            for(quickbook::string_view::const_iterator
                 first = value.begin(), last  = value.end();
                 first != last; ++first)
             {
@@ -1201,7 +1207,7 @@ namespace quickbook
             //                 then use whitespace to separate them
             //                 (2 = template name + argument).
 
-            if (qbk_version_n < 105 || args.size() == 1)
+            if (qbk_version_n < 105 ? args.size() : args.size() == 1)
             {
            
                 while (args.size() < params.size())
@@ -1267,7 +1273,7 @@ namespace quickbook
             file_ptr saved_current_file = state.current_file;
 
             state.current_file = content.get_file();
-            boost::string_ref source = content.get_quickbook();
+            quickbook::string_view source = content.get_quickbook();
 
             parse_iterator first(source.begin());
             parse_iterator last(source.end());
@@ -1732,6 +1738,7 @@ namespace quickbook
         values.finish();
 
         std::string full_id = state.document.begin_section(
+            element_id,
             element_id.empty() ?
                 detail::make_identifier(content.get_quickbook()) :
                 validate_id(state, element_id),
@@ -1741,27 +1748,33 @@ namespace quickbook
             state.current_source_mode());
 
         state.out << "\n<section id=\"" << full_id << "\">\n";
-        state.out << "<title>";
 
-        write_anchors(state, state.out);
+        std::string title = content.get_encoded();
 
-        if (self_linked_headers && state.document.compatibility_version() >= 103)
-        {
-            state.out << "<link linkend=\"" << full_id << "\">"
-                << content.get_encoded()
-                << "</link>"
-                ;
+        if (!title.empty()) {
+            state.out << "<title>";
+
+            write_anchors(state, state.out);
+
+            if (self_linked_headers && state.document.compatibility_version() >= 103)
+            {
+                state.out << quickbook::detail::linkify(title, full_id);
+            }
+            else
+            {
+                state.out << title;
+            }
+
+            state.out << "</title>\n";
         }
-        else
-        {
-            state.out << content.get_encoded();
-        }
-        
-        state.out << "</title>\n";
     }
 
-    void end_section_action(quickbook::state& state, value end_section, string_iterator first)
+    void end_section_action(quickbook::state& state, value end_section_list, string_iterator first)
     {
+        value_consumer values = end_section_list;
+        value element_id = values.optional_consume(general_tags::element_id);
+        values.finish();
+
         write_anchors(state, state.out);
 
         if (state.document.section_level() <= state.min_section_level)
@@ -1775,6 +1788,29 @@ namespace quickbook
             return;
         }
 
+        if (!element_id.empty() && !(element_id == state.document.explicit_id()))
+        {
+            file_position const pos = state.current_file->position_of(first);
+            value section_element_id = state.document.explicit_id();
+
+            if (section_element_id.empty()) {
+                detail::outerr(state.current_file->path, pos.line)
+                    << "Endsect has unexpected id '"
+                    << element_id.get_quickbook()
+                    << "' in section with no explicit id, near column "
+                    << pos.column << ".\n";
+            } else {
+                detail::outerr(state.current_file->path, pos.line)
+                    << "Endsect has incorrect id '"
+                    << element_id.get_quickbook()
+                    << "', expected '"
+                    << state.document.explicit_id().get_quickbook()
+                    << "', near column "
+                    << pos.column << ".\n";
+            }
+            ++state.error_count;
+        }
+
         state.out << "</section>";
         state.document.end_section();
     }
