@@ -18,6 +18,8 @@
 #include "template_stack.hpp"
 #include "symbols.hpp"
 #include "dependency_tracker.hpp"
+#include "syntax_highlight.hpp"
+#include "include_paths.hpp"
 
 namespace quickbook
 {
@@ -27,7 +29,7 @@ namespace quickbook
     struct state
     {
         state(fs::path const& filein_, fs::path const& xinclude_base, string_stream& out_,
-                id_manager&);
+                document_state&);
 
     private:
         boost::scoped_ptr<quickbook_grammar> grammar_;
@@ -42,27 +44,30 @@ namespace quickbook
         static int const max_template_depth = 100;
 
     // global state
+        unsigned                order_pos;
         fs::path                xinclude_base;
         template_stack          templates;
         int                     error_count;
         string_list             anchors;
         bool                    warned_about_breaks;
         bool                    conditional;
-        id_manager&             ids;
+        document_state&         document;
         value_builder           callouts;           // callouts are global as
         int                     callout_depth;      // they don't nest.
         dependency_tracker      dependencies;
         bool                    explicit_list;      // set when using a list
+        bool                    strict_mode;
 
     // state saved for files and templates.
         bool                    imported;
         string_symbols          macro;
-        std::string             source_mode;
-        value                   source_mode_next;
+        source_mode_info        source_mode;
+        source_mode_type        source_mode_next;
+        value                   source_mode_next_pos;
+        std::vector<source_mode_info>
+                                tagged_source_mode_stack;
         file_ptr                current_file;
-        fs::path                filename_relative;  // for the __FILENAME__ macro.
-                                                    // (relative to the original file
-                                                    //  or include path).
+        quickbook_path          current_path;
 
     // state saved for templates.
         int                     template_depth;
@@ -86,6 +91,8 @@ namespace quickbook
 
         void update_filename_macro();
 
+        unsigned get_new_order_pos();
+
         void push_output();
         void pop_output();
 
@@ -97,6 +104,12 @@ namespace quickbook
         void start_callouts();
         std::string add_callout(value);
         std::string end_callouts();
+
+        source_mode_info current_source_mode() const;
+        source_mode_info tagged_source_mode() const;
+        void change_source_mode(source_mode_type);
+        void push_tagged_source_mode(source_mode_type);
+        void pop_tagged_source_mode();
     };
 
     extern unsigned qbk_version_n; // qbk_major_version * 100 + qbk_minor_version
